@@ -9,24 +9,24 @@
 #' @section Details:
 #' The `as_flex_table()` functions converts the gtsummary object to a flextable,
 #' and prints it with the following styling functions.
-#' 1. [flextable::flextable()]
-#' 1. [flextable::set_header_labels()] to set column labels
-#' 1. [flextable::add_header_row()], if applicable, to set spanning column header
-#' 1. [flextable::align()] to set column alignment
-#' 1. [flextable::padding()] to indent variable levels
-#' 1. [flextable::fontsize()] to set font size
-#' 1. [flextable::autofit()] to estimate the column widths
-#' 1. [flextable::footnote()] to add table footnotes and source notes
-#' 1. [flextable::bold()] to bold cells in data frame
-#' 1. [flextable::italic()] to italicize cells in data frame
-#' 1. [flextable::border()] to set all border widths to 1
-#' 1. [flextable::padding()] to set consistent header padding
-#' 1. [flextable::valign()] to ensure label column is top-left justified
+#' 1. `flextable::flextable()`
+#' 1. `flextable::set_header_labels()` to set column labels
+#' 1. `flextable::add_header_row()`, if applicable, to set spanning column header
+#' 1. `flextable::align()` to set column alignment
+#' 1. `flextable::padding()` to indent variable levels
+#' 1. `flextable::fontsize()` to set font size
+#' 1. `flextable::autofit()` to estimate the column widths
+#' 1. `flextable::footnote()` to add table footnotes and source notes
+#' 1. `flextable::bold()` to bold cells in data frame
+#' 1. `flextable::italic()` to italicize cells in data frame
+#' 1. `flextable::border()` to set all border widths to 1
+#' 1. `flextable::padding()` to set consistent header padding
+#' 1. `flextable::valign()` to ensure label column is top-left justified
 #'
 #' Any one of these commands may be omitted using the `include=` argument.
 #'
-#' Pro tip: Use the [flextable::width()] function for exacting control over
-#' column width after calling [as_flex_table()].
+#' Pro tip: Use the `flextable::width()` function for exacting control over
+#' column width after calling `as_flex_table()`.
 #' @inheritParams as_gt
 #' @inheritParams as_tibble.gtsummary
 #' @param strip_md_bold When TRUE, all double asterisk (markdown language for
@@ -52,28 +52,38 @@ as_flex_table <- function(x, include = everything(), return_calls = FALSE,
   # checking flextable installation --------------------------------------------
   assert_package("flextable", "as_flex_table()")
 
+  # running pre-conversion function, if present --------------------------------
+  x <- do.call(get_theme_element("pkgwide-fun:pre_conversion", default = identity), list(x))
+
+  # converting row specifications to row numbers, and removing old cmds --------
+  x <- .clean_table_styling(x)
+
   # stripping markdown asterisk ------------------------------------------------
   if (strip_md_bold == TRUE) {
-    x$table_header <-
-      x$table_header %>%
+    x$table_styling$header <-
+      x$table_styling$header %>%
       mutate_at(
         vars(.data$label, .data$spanning_header),
-        ~str_replace_all(., pattern = fixed("**"), replacement = fixed(""))
+        ~ str_replace_all(., pattern = fixed("**"), replacement = fixed(""))
       )
   }
 
   # creating list of flextable calls -------------------------------------------
-  flextable_calls <- table_header_to_flextable_calls(x = x)
+  flextable_calls <- table_styling_to_flextable_calls(x = x)
 
   # adding user-specified calls ------------------------------------------------
   insert_expr_after <- get_theme_element("as_flex_table-lst:addl_cmds")
   flextable_calls <-
     purrr::reduce(
       .x = seq_along(insert_expr_after),
-      .f = function(x, y) add_expr_after(calls = x,
-                                         add_after = names(insert_expr_after[y]),
-                                         expr = insert_expr_after[[y]],
-                                         new_name = paste0("user_added", y)),
+      .f = function(x, y) {
+        add_expr_after(
+          calls = x,
+          add_after = names(insert_expr_after[y]),
+          expr = insert_expr_after[[y]],
+          new_name = paste0("user_added", y)
+        )
+      },
       .init = flextable_calls
     )
 
@@ -86,7 +96,9 @@ as_flex_table <- function(x, include = everything(), return_calls = FALSE,
     )
 
   # return calls, if requested -------------------------------------------------
-  if (return_calls == TRUE) return(flextable_calls[include])
+  if (return_calls == TRUE) {
+    return(flextable_calls[include])
+  }
 
   # taking each kable function call, concatenating them with %>% separating them
   flextable_calls[include] %>%
@@ -99,12 +111,12 @@ as_flex_table <- function(x, include = everything(), return_calls = FALSE,
     eval()
 }
 
-# creating flextable calls from table_header -----------------------------------
-table_header_to_flextable_calls <- function(x, ...) {
+# creating flextable calls from table_styling ----------------------------------
+table_styling_to_flextable_calls <- function(x, ...) {
 
   # adding id number for columns not hidden
-  table_header <-
-    .clean_table_header(x$table_header) %>%
+  x$table_styling$header <-
+    x$table_styling$header %>%
     group_by(.data$hide) %>%
     mutate(id = ifelse(.data$hide == FALSE, dplyr::row_number(), NA)) %>%
     ungroup()
@@ -112,46 +124,50 @@ table_header_to_flextable_calls <- function(x, ...) {
   # tibble ---------------------------------------------------------------------
   # flextable doesn't use the markdown language `__` or `**`
   # to bold and italicize text, so removing them here
-  flextable_calls <-
-    as_tibble(x, return_calls = TRUE,
-              include = -c("cols_label", "tab_style_bold", "tab_style_italic"))
+  flextable_calls <- table_styling_to_tibble_calls(x, col_labels = FALSE)
+  flextable_calls$tab_style_bold <- flextable_calls$tab_style_italic <- NULL
 
   # flextable ------------------------------------------------------------------
   flextable_calls[["flextable"]] <- expr(flextable::flextable())
 
   # set_header_labels ----------------------------------------------------------
   col_labels <-
-    table_header %>%
+    x$table_styling$header %>%
     filter(.data$hide == FALSE) %>%
-    {set_names(as.list(.[["label"]]), .[["column"]])}
+    select(.data$column, .data$label) %>%
+    tibble::deframe()
 
   flextable_calls[["set_header_labels"]] <- expr(
     flextable::set_header_labels(!!!col_labels)
   )
 
   # set_caption ----------------------------------------------------------------
-  if (!is.null(x$list_output$caption)) {
+  if (!is.null(x$table_styling$caption)) {
     flextable_calls[["set_caption"]] <- expr(
-      flextable::set_caption(caption = !!x$list_output$caption)
+      flextable::set_caption(caption = !!x$table_styling$caption)
     )
   }
 
   # add_header_row -------------------------------------------------------------
   # this is the spanning rows
-  any_spanning_header <- sum(!is.na(table_header$spanning_header)) > 0
-  if (any_spanning_header == FALSE) flextable_calls[["add_header_row"]] <- list()
-  else {
+  any_spanning_header <- any(!is.na(x$table_styling$header$spanning_header))
+  if (any_spanning_header == FALSE) {
+    flextable_calls[["add_header_row"]] <- list()
+  } else {
     df_header0 <-
-      table_header %>%
+      x$table_styling$header %>%
       filter(.data$hide == FALSE) %>%
       select(.data$spanning_header) %>%
-      mutate(spanning_header = ifelse(is.na(.data$spanning_header),
-                                      " ", .data$spanning_header),
-             spanning_header_id = dplyr::row_number())
+      mutate(
+        spanning_header = ifelse(is.na(.data$spanning_header),
+          " ", .data$spanning_header
+        ),
+        spanning_header_id = dplyr::row_number()
+      )
     # assigning an ID for each spanning header group
     for (i in seq(2, nrow(df_header0))) {
-      if(df_header0$spanning_header[i] == df_header0$spanning_header[i-1]) {
-        df_header0$spanning_header_id[i] <- df_header0$spanning_header_id[i-1]
+      if (df_header0$spanning_header[i] == df_header0$spanning_header[i - 1]) {
+        df_header0$spanning_header_id[i] <- df_header0$spanning_header_id[i - 1]
       }
     }
 
@@ -175,7 +191,7 @@ table_header_to_flextable_calls <- function(x, ...) {
 
   # align ----------------------------------------------------------------------
   df_align <-
-    table_header %>%
+    x$table_styling$header %>%
     filter(.data$hide == FALSE) %>%
     select(.data$id, .data$align) %>%
     group_by(.data$align) %>%
@@ -184,24 +200,26 @@ table_header_to_flextable_calls <- function(x, ...) {
 
   flextable_calls[["align"]] <- map2(
     df_align$align, df_align$data,
-    ~expr(flextable::align(align = !!.x, j = !!.y$id, part = "all"))
+    ~ expr(flextable::align(align = !!.x, j = !!.y$id, part = "all"))
   )
 
   # padding --------------------------------------------------------------------
   df_padding <-
-    table_header %>%
-    filter(!is.na(.data$indent)) %>%
-    select(.data$id, .data$column, .data$indent) %>%
-    mutate(
-      i_index = map(
-        .data$indent,
-        ~rlang::eval_tidy(rlang::parse_expr(.x), x$table_body) %>% which()
-      )
+    x$table_styling$header %>%
+    select(.data$id, .data$column) %>%
+    inner_join(
+      x$table_styling$text_format %>%
+        filter(.data$format_type == "indent"),
+      by = "column"
     )
 
-  flextable_calls[["padding"]] <- map2(
-    df_padding$id, df_padding$i_index,
-    ~expr(flextable::padding(i = !!.y, j = !!.x, padding.left = 15))
+  flextable_calls[["padding"]] <- map(
+    seq_len(nrow(df_padding)),
+    ~ expr(flextable::padding(
+      i = !!df_padding$row_numbers[[.x]],
+      j = !!df_padding$id[[.x]],
+      padding.left = 15
+    ))
   )
 
   # fontsize -------------------------------------------------------------------
@@ -213,109 +231,114 @@ table_header_to_flextable_calls <- function(x, ...) {
   flextable_calls[["autofit"]] <- expr(flextable::autofit())
 
   # footnote -------------------------------------------------------------------
-  i_index <- ifelse(any_spanning_header == TRUE, 2L, 1L)
-
-  footnote_abbrev <-
-    table_header %>%
-    select(.data$id, .data$footnote_abbrev) %>%
-    filter(!is.na(.data$footnote_abbrev)) %>%
-    group_by(.data$footnote_abbrev) %>%
-    nest() %>%
-    ungroup() %>%
-    mutate(footnote = paste(.data$footnote_abbrev, collapse = ", ")) %>%
-    unnest(cols = .data$data) %>%
-    select(-.data$footnote_abbrev) %>%
-    group_by(.data$footnote) %>%
-    nest() %>%
-    ungroup()
+  header_i_index <- ifelse(any_spanning_header == TRUE, 2L, 1L)
 
   df_footnote <-
-    table_header %>%
-    select(.data$id, .data$footnote) %>%
-    filter(!is.na(.data$footnote)) %>%
-    group_by(.data$footnote) %>%
-    nest() %>%
-    ungroup() %>%
-    bind_rows(footnote_abbrev) %>%
-    mutate(
-      j_index = map(.data$data, ~.x$id),
-      min_id = purrr::map_int(.data$j_index,~min(.x))
+    .number_footnotes(x) %>%
+    inner_join(x$table_styling$header %>%
+      select(.data$column, column_id = .data$id),
+    by = "column"
     ) %>%
-    arrange(.data$min_id) %>%
-    mutate(row_number = dplyr::row_number())
-
-  flextable_calls[["footnote"]] <- pmap(
-    list(df_footnote$j_index, df_footnote$footnote, df_footnote$row_number),
-    ~expr(
-      flextable::footnote(
-        i = !!i_index, j = !!..1,
-        value = flextable::as_paragraph(!!..2),
-        part = "header", ref_symbols = !!..3
-      )
-    )
-  )
-
-  # fmt_missing_emdash ---------------------------------------------------------
-  df_na_emdash <-
-    table_header %>%
-    filter(!is.na(.data$missing_emdash)) %>%
-    select(.data$id, .data$column, .data$missing_emdash) %>%
+    mutate(row_numbers = ifelse(.data$tab_location == "header",
+      header_i_index,
+      .data$row_numbers
+    )) %>%
+    select(
+      .data$footnote_id, .data$footnote, .data$tab_location,
+      .data$row_numbers, .data$column_id
+    ) %>%
+    nest(location_ids = c(.data$row_numbers, .data$column_id)) %>%
     mutate(
-      i_index = map(
-        .data$missing_emdash,
-        ~rlang::eval_tidy(rlang::parse_expr(.x), x$table_body) %>% which()
+      row_numbers = map(.data$location_ids, ~ pluck(.x, "row_numbers") %>% unique()),
+      column_id = map(.data$location_ids, ~ pluck(.x, "column_id") %>% unique())
+    )
+
+  flextable_calls[["footnote"]] <-
+    map(
+      seq_len(nrow(df_footnote)),
+      ~ expr(
+        flextable::footnote(
+          i = !!df_footnote$row_numbers[[.x]],
+          j = !!df_footnote$column_id[[.x]],
+          value = flextable::as_paragraph(!!df_footnote$footnote[[.x]]),
+          part = !!df_footnote$tab_location[[.x]],
+          ref_symbols = !!df_footnote$footnote_id[[.x]]
+        )
       )
     )
 
-  flextable_calls[["fmt_missing_emdash"]] <-
-    map2(
-      df_na_emdash$i_index, df_na_emdash$id,
-      ~expr(
-        flextable::colformat_char(j = !!.y, i = !!.x,
-                                  na_str = !!get_theme_element("tbl_regression-str:ref_row_text", default = "\U2014"))
+  # fmt_missing ----------------------------------------------------------------
+  df_fmt_missing <-
+    x$table_styling$fmt_missing %>%
+    inner_join(x$table_styling$header %>%
+      select(.data$column, column_id = .data$id),
+    by = "column"
+    ) %>%
+    select(.data$symbol, .data$row_numbers, .data$column_id) %>%
+    nest(location_ids = c(.data$row_numbers, .data$column_id)) %>%
+    mutate(
+      row_numbers = map(.data$location_ids, ~ pluck(.x, "row_numbers") %>% unique()),
+      column_id = map(.data$location_ids, ~ pluck(.x, "column_id") %>% unique())
+    )
+
+  flextable_calls[["fmt_missing"]] <-
+    map(
+      seq_len(nrow(df_fmt_missing)),
+      ~ expr(
+        flextable::colformat_char(
+          i = !!df_fmt_missing$row_numbers[[.x]],
+          j = !!df_fmt_missing$column_id[[.x]],
+          na_str = !!df_fmt_missing$symbol[[.x]]
         )
+      )
     )
 
   # bold -----------------------------------------------------------------------
   df_bold <-
-    table_header %>%
-    filter(!is.na(.data$bold)) %>%
-    select(.data$id, .data$column, .data$bold) %>%
-    mutate(
-      i_index = map(
-        .data$bold,
-        ~rlang::eval_tidy(rlang::parse_expr(.x), x$table_body) %>% which()
-      )
-    )
+    x$table_styling$text_format %>%
+    filter(.data$format_type == "bold") %>%
+    inner_join(x$table_styling$header %>%
+      select(.data$column, column_id = .data$id),
+    by = "column"
+    ) %>%
+    select(.data$format_type, .data$row_numbers, .data$column_id)
 
-  flextable_calls[["bold"]] <- map2(
-    df_bold$id, df_bold$i_index,
-    ~expr(flextable::bold(i = !!.y, j = !!.x, part = "body"))
-  )
+  flextable_calls[["bold"]] <-
+    map(
+      seq_len(nrow(df_bold)),
+      ~ expr(flextable::bold(
+        i = !!df_bold$row_numbers[[.x]],
+        j = !!df_bold$column_id[[.x]],
+        part = "body"
+      ))
+    )
 
   # italic ---------------------------------------------------------------------
   df_italic <-
-    table_header %>%
-    filter(!is.na(.data$italic)) %>%
-    select(.data$id, .data$column, .data$italic) %>%
-    mutate(
-      i_index = map(
-        .data$italic,
-        ~rlang::eval_tidy(rlang::parse_expr(.x), x$table_body) %>% which()
-      )
-    )
+    x$table_styling$text_format %>%
+    filter(.data$format_type == "italic") %>%
+    inner_join(x$table_styling$header %>%
+      select(.data$column, column_id = .data$id),
+    by = "column"
+    ) %>%
+    select(.data$format_type, .data$row_numbers, .data$column_id)
 
-  flextable_calls[["italic"]] <- map2(
-    df_italic$id, df_italic$i_index,
-    ~expr(flextable::italic(i = !!.y, j = !!.x, part = "body"))
-  )
+  flextable_calls[["italic"]] <-
+    map(
+      seq_len(nrow(df_italic)),
+      ~ expr(flextable::italic(
+        i = !!df_italic$row_numbers[[.x]],
+        j = !!df_italic$column_id[[.x]],
+        part = "body"
+      ))
+    )
 
   # source note ----------------------------------------------------------------
   # in flextable, this is just a footnote associated without column or symbol
-  if (!is.null(x$list_output$source_note)) {
+  if (!is.null(x$table_styling$source_note)) {
     flextable_calls[["source_note"]] <-
       expr(
-        flextable::footnote(value = flextable::as_paragraph(!!x$list_output$source_note), ref_symbols = "")
+        flextable::footnote(value = flextable::as_paragraph(!!x$table_styling$source_note), ref_symbols = "")
       )
   }
 
@@ -340,6 +363,21 @@ table_header_to_flextable_calls <- function(x, ...) {
       )
     )
 
+  # horizontal_line_above ------------------------------------------------------
+  if (!is.null(x$table_styling$horizontal_line_above)) {
+    row_number <-
+      eval_tidy(x$table_styling$horizontal_line_above, data = x$table_body) %>%
+      which()
+    flextable_calls[["horizontal_line"]] <-
+      expr(
+        flextable::border(
+          i = !!row_number,
+          border.top = officer::fp_border(width = 1),
+          part = "body"
+        )
+      )
+  }
+
   # padding for header ---------------------------------------------------------
   # setting all header rows to the same padding
   flextable_calls[["padding_header"]] <-
@@ -362,4 +400,3 @@ table_header_to_flextable_calls <- function(x, ...) {
 
   flextable_calls
 }
-
