@@ -1,11 +1,10 @@
 #' Create a table of summary statistics from a survey object
 #'
-#' \lifecycle{experimental}
 #' The `tbl_svysummary` function calculates descriptive statistics for
 #' continuous, categorical, and dichotomous variables taking into account survey weights and design.
 #' It is similar to [tbl_summary()].
 #'
-#' @param data A survey object created with created with [survey::svydesign()]
+#' @param data A survey object created with created with `survey::svydesign()`
 #' @inheritParams tbl_summary
 #'
 #' @inheritSection tbl_summary type argument
@@ -89,9 +88,9 @@
 #'
 #' \if{html}{\figure{tbl_svysummary_ex2.png}{options: width=36\%}}
 tbl_svysummary <- function(data, by = NULL, label = NULL, statistic = NULL,
-                        digits = NULL, type = NULL, value = NULL,
-                        missing = NULL, missing_text = NULL, sort = NULL,
-                        percent = NULL, include = NULL) {
+                           digits = NULL, type = NULL, value = NULL,
+                           missing = NULL, missing_text = NULL, sort = NULL,
+                           percent = NULL, include = everything()) {
   # checking for survey package ------------------------------------------------
   assert_package("survey", "tbl_svysummary()")
 
@@ -99,24 +98,7 @@ tbl_svysummary <- function(data, by = NULL, label = NULL, statistic = NULL,
   if (!is_survey(data)) stop("'data' should be a survey object (see svydesign()).", call. = FALSE)
 
   # eval -----------------------------------------------------------------------
-  include <- select(data$variables, {{ include }}) %>% names()
-
-  # default selection for include
-  if (length(include) == 0) {
-    # look at data$call
-    if (is.null(data$call)) {
-      include <- names(data$variables)
-    } else {
-      exclude <- c(
-        all.vars(data$call$id),
-        all.vars(data$call$probs),
-        all.vars(data$call$strata),
-        all.vars(data$call$fpc),
-        all.vars(data$call$weights)
-      )
-      include <- setdiff(names(data$variables), exclude)
-    }
-  }
+  include <- select(.remove_survey_cols(data), {{ include }}) %>% names()
 
   # setting defaults from gtsummary theme --------------------------------------
   label <- label %||%
@@ -140,7 +122,8 @@ tbl_svysummary <- function(data, by = NULL, label = NULL, statistic = NULL,
   missing_text <- missing_text %||%
     get_theme_element("tbl_svysummary-arg:missing_text") %||%
     get_theme_element("tbl_summary-arg:missing_text",
-                      default = translate_text("Unknown"))
+      default = translate_text("Unknown")
+    )
   sort <- sort %||%
     get_theme_element("tbl_svysummary-arg:sort") %||%
     get_theme_element("tbl_summary-arg:sort")
@@ -164,11 +147,6 @@ tbl_svysummary <- function(data, by = NULL, label = NULL, statistic = NULL,
   # checking input data --------------------------------------------------------
   tbl_summary_data_checks(data$variables)
 
-  # removing ordered class from factor by variables ----------------------------
-  if (!is.null(by) && inherits(data$variables[[by]], "ordered") && inherits(data$variables[[by]], "factor")) {
-    data$variables[[by]] <- factor(data$variables[[by]], ordered = FALSE)
-  }
-
   # if by is numeric, convert into a factor -------------------------------
   if (!is.null(by) && is.numeric(data$variables[[by]])) {
     data$variables[[by]] <- factor(data$variables[[by]], ordered = FALSE)
@@ -198,26 +176,27 @@ tbl_svysummary <- function(data, by = NULL, label = NULL, statistic = NULL,
   tbl_summary_inputs <- as.list(environment())
   tbl_summary_inputs$exclude <- NULL # should not be exported
 
-  # removing variables with unsupported variable types from data ---------------
-  classes_expected <- c("character", "factor", "numeric", "logical", "integer", "difftime")
-  data$variables <- removing_variables_with_unsupported_types(data$variables, include, classes_expected)
-
   # checking function inputs ---------------------------------------------------
   tbl_summary_input_checks(
     data$variables, by, label, type, value, statistic,
     digits, missing, missing_text, sort
   )
 
+  # removing variables not selected for summary --------------------------------
+  data$variables <- select(data$variables, !!include)
+
   # generate meta_data --------------------------------------------------------
-  meta_data <- generate_metadata(data$variables, value, by, classes_expected, type, label, statistic, digits, percent, sort, survey = data)
+  meta_data <- generate_metadata(data$variables, value, by, type, label, statistic, digits, percent, sort, survey = data)
 
   # calculating summary statistics ---------------------------------------------
   table_body <-
     meta_data %>%
     mutate(
       tbl_stats = pmap(
-        list(.data$summary_type, .data$variable,
-             .data$var_label, .data$stat_display, .data$df_stats),
+        list(
+          .data$summary_type, .data$variable,
+          .data$var_label, .data$stat_display, .data$df_stats
+        ),
         function(summary_type, variable, var_label, stat_display, df_stats) {
           df_stats_to_tbl(
             data = data, variable = variable, summary_type = summary_type, by = by,
@@ -225,57 +204,47 @@ tbl_svysummary <- function(data, by = NULL, label = NULL, statistic = NULL,
             df_stats = df_stats, missing = missing, missing_text = missing_text
           )
         }
-      ),
-      var_class = map_chr(.data$class, pluck, 1)
+      )
     ) %>%
-    select(var_type = .data$summary_type, .data$var_class, .data$var_label, .data$tbl_stats) %>%
+    select(var_type = .data$summary_type, .data$var_label, .data$tbl_stats) %>%
     unnest(.data$tbl_stats) %>%
-    select(.data$variable, .data$var_type, .data$var_class, .data$var_label, everything())
+    select(.data$variable, .data$var_type, .data$var_label, everything())
 
   # table of column headers ----------------------------------------------------
-  table_header <-
-    tibble(column = names(table_body)) %>%
-    table_header_fill_missing()
+  x <-
+    .create_gtsummary_object(
+      table_body = table_body,
+      meta_data = meta_data,
+      inputs = tbl_summary_inputs,
+      N = nrow(data),
+      call_list = list(tbl_summary = match.call()),
+      by = by,
+      df_by = df_by(data, by)
+    )
 
   # adding stat footnote (unless there are continuous2 vars)
   if (!"continuous2" %in% meta_data$summary_type) {
-    table_header <-
-      table_header %>%
-      mutate(
-        # adding footnote of statistics on display (unless theme indicates a no print)
-        footnote = ifelse(
-          startsWith(.data$column, "stat_"),
-          footnote_stat_label(meta_data),
-          .data$footnote
-        )
+    x <-
+      modify_table_styling(
+        x,
+        columns = starts_with("stat_"),
+        footnote = footnote_stat_label(meta_data)
       )
   }
 
-  # returning all results in a list --------------------------------------------
-  results <- list(
-    table_body = table_body,
-    table_header = table_header,
-    meta_data = meta_data,
-    inputs = tbl_summary_inputs,
-    N = round(sum(weights(data))),
-    call_list = list(tbl_summary = match.call())
-  )
-  results$by <- by
-  results$df_by <- df_by(data, by)
-
   # assigning a class of tbl_summary (for special printing in Rmarkdown)
-  class(results) <- c("tbl_svysummary", "gtsummary")
+  class(x) <- c("tbl_svysummary", class(x))
 
   # adding headers
   if (is.null(by)) {
-    results <- modify_header(
-      results,
+    x <- modify_header(
+      x,
       stat_0 = "**N = {style_number(N)}**",
       label = paste0("**", translate_text("Characteristic"), "**")
     )
   } else {
-    results <- modify_header(
-      results,
+    x <- modify_header(
+      x,
       update = list(
         all_stat_cols(FALSE) ~ "**{level}**, N = {style_number(n)}",
         label ~ paste0("**", translate_text("Characteristic"), "**")
@@ -283,7 +252,13 @@ tbl_svysummary <- function(data, by = NULL, label = NULL, statistic = NULL,
     )
   }
 
-  return(results)
+  # running any additional mods ------------------------------------------------
+  x <-
+    get_theme_element("tbl_svysummary-fn:addnl-fn-to-run", default = identity) %>%
+    do.call(list(x))
+
+  # returning tbl_svysummary table ---------------------------------------------
+  x
 }
 
 #' Test if data is a survey object
@@ -293,16 +268,18 @@ is_survey <- function(data) {
 }
 
 # summarize_categorical for survey design --------------------------------------
-summarize_categorical_survey <- function(data, variable, by, class,
+summarize_categorical_survey <- function(data, variable, by,
                                          dichotomous_value, sort, percent, stat_display) {
   df_stats <-
-    summarize_categorical(data = data$variables, variable = variable, by = by,
-                          class = class, dichotomous_value = dichotomous_value,
-                          sort = sort, percent = percent, stat_display = stat_display) %>%
+    summarize_categorical(
+      data = data$variables, variable = variable, by = by,
+      dichotomous_value = dichotomous_value,
+      sort = sort, percent = percent, stat_display = stat_display
+    ) %>%
     rename(n_unweighted = .data$n, N_unweighted = .data$N, p_unweighted = .data$p)
 
   # if there is a dichotomous value, it needs to be present as a level of the variable for svytable
-  if(!is.null(dichotomous_value) && !dichotomous_value %in% unique(data$variables[[variable]])) {
+  if (!is.null(dichotomous_value) && !dichotomous_value %in% unique(data$variables[[variable]])) {
     data$variables[[variable]] <- as.factor(data$variables[[variable]])
     levels(data$variables[[variable]]) <- c(levels(data$variables[[variable]]), dichotomous_value)
   }
@@ -323,8 +300,7 @@ summarize_categorical_survey <- function(data, variable, by, class,
     )
 
   # calculating percent
-  group_by_percent <- switch(
-    percent,
+  group_by_percent <- switch(percent,
     "cell" = "",
     "column" = ifelse(!is.null(by), "by", ""),
     "row" = "variable_levels"
@@ -366,9 +342,11 @@ summarize_continuous_survey <- function(data, variable, by, stat_display,
   fns_names_chr <-
     extracting_function_calls_from_stat_display(stat_display, variable) %>%
     # removing stats that are calculated later
-    setdiff(c("p_miss", "N_obs", "N_miss", "p_miss_unweighted", "N_obs_unweighted",
-              "N_miss_unweighted", "N_nonmiss", "p_nonmiss", "N_nonmiss_unweighted",
-              "p_nonmiss_unweighted"))
+    setdiff(c(
+      "p_miss", "N_obs", "N_miss", "p_miss_unweighted", "N_obs_unweighted",
+      "N_miss_unweighted", "N_nonmiss", "p_nonmiss", "N_nonmiss_unweighted",
+      "p_nonmiss_unweighted"
+    ))
 
 
   # preparing df_stats
@@ -391,8 +369,10 @@ summarize_continuous_survey <- function(data, variable, by, stat_display,
     return <-
       left_join(
         df_stats,
-        tibble(variable_levels = map_chr(stat_display, ~stat_label_match(.x) %>% unlist()),
-               stat_display = .env$stat_display),
+        tibble(
+          variable_levels = map_chr(stat_display, ~ stat_label_match(.x) %>% unlist()),
+          stat_display = .env$stat_display
+        ),
         by = character()
       ) %>%
       select(any_of(c("by", "variable", "variable_levels", "stat_display")), everything())
@@ -410,8 +390,9 @@ summarize_continuous_survey <- function(data, variable, by, stat_display,
 
 compute_survey_stat <- function(data, variable, by, f) {
   # difftime variable needs to be transformed into numeric for svyquantile
-  if (inherits(data$variables[[variable]], "difftime"))
+  if (inherits(data$variables[[variable]], "difftime")) {
     data$variables[[variable]] <- unclass(data$variables[[variable]])
+  }
 
   args <- list(
     design = data,
@@ -420,8 +401,9 @@ compute_survey_stat <- function(data, variable, by, f) {
   )
 
   # if all values are NA, turn na.rm to FALSE to avoid error
-  if (all(is.na(data$variables[[variable]])))
+  if (all(is.na(data$variables[[variable]]))) {
     args$na.rm <- FALSE
+  }
 
   fun <- NULL
   if (f == "mean") {
@@ -438,20 +420,19 @@ compute_survey_stat <- function(data, variable, by, f) {
     args$quantiles <- .5
   }
   if (f == "min") {
-    fun <- survey::svyquantile
-    args$quantiles <- 0
+    fun <- svymin
   }
   if (f == "max") {
-    fun <- survey::svyquantile
-    args$quantiles <- 1
+    fun <- svymax
   }
   if (f %in% paste0("p", 0:100)) {
     fun <- survey::svyquantile
     args$quantiles <- as.numeric(stringr::str_replace(f, pattern = "^p", "")) / 100
   }
 
-  if (is.null(fun))
+  if (is.null(fun)) {
     stop(paste0("'", f, "' statistic is not supported for survey objects."), call. = FALSE)
+  }
 
   if (is.null(by)) {
     args$x <- c_form(right = variable)
@@ -470,8 +451,9 @@ compute_survey_stat <- function(data, variable, by, f) {
       mutate(variable = variable)
   }
 
-  if (f == "sd")
+  if (f == "sd") {
     stat$sd <- sqrt(stat$sd)
+  }
 
   stat
 }
@@ -479,27 +461,34 @@ compute_survey_stat <- function(data, variable, by, f) {
 # df_stats_fun_survey -----------------------------------------------------------
 # this function creates df_stats in the tbl_svysummary meta data table
 # and includes the number of missing values
-df_stats_fun_survey <- function(summary_type, variable, class, dichotomous_value, sort,
-                                stat_display, digits, data, by, percent) {
+df_stats_fun_survey <- function(summary_type, variable, dichotomous_value, sort,
+                                stat_display, digits, data, by, percent, var_label) {
   # first table are the standard stats
-  t1 <- switch(
-    summary_type,
-    "continuous" = summarize_continuous_survey(data = data, variable = variable,
-                                               by = by, stat_display = stat_display,
-                                               digits = digits, summary_type = summary_type),
-    "continuous2" = summarize_continuous_survey(data = data, variable = variable,
-                                                by = by, stat_display = stat_display,
-                                                digits = digits, summary_type = summary_type),
-    "categorical" = summarize_categorical_survey(data = data, variable = variable,
-                                                 by = by, class = class,
-                                                 dichotomous_value = dichotomous_value,
-                                                 sort = sort, percent = percent,
-                                                 stat_display = stat_display),
-    "dichotomous" = summarize_categorical_survey(data = data, variable = variable,
-                                                 by = by, class = class,
-                                                 dichotomous_value = dichotomous_value,
-                                                 sort = sort, percent = percent,
-                                                 stat_display = stat_display)
+  t1 <- switch(summary_type,
+    "continuous" = summarize_continuous_survey(
+      data = data, variable = variable,
+      by = by, stat_display = stat_display,
+      digits = digits, summary_type = summary_type
+    ),
+    "continuous2" = summarize_continuous_survey(
+      data = data, variable = variable,
+      by = by, stat_display = stat_display,
+      digits = digits, summary_type = summary_type
+    ),
+    "categorical" = summarize_categorical_survey(
+      data = data, variable = variable,
+      by = by,
+      dichotomous_value = dichotomous_value,
+      sort = sort, percent = percent,
+      stat_display = stat_display
+    ),
+    "dichotomous" = summarize_categorical_survey(
+      data = data, variable = variable,
+      by = by,
+      dichotomous_value = dichotomous_value,
+      sort = sort, percent = percent,
+      stat_display = stat_display
+    )
   )
 
   # adding the N_obs and N_missing, etc
@@ -507,28 +496,53 @@ df_stats_fun_survey <- function(summary_type, variable, class, dichotomous_value
   # for svytable, we need to be sure that the factor has two levels
   data_is_na$variables <- mutate_at(data$variables, vars(all_of(variable)), ~ factor(is.na(.), c(F, T)))
 
-  t2 <- summarize_categorical_survey(data = data_is_na,
-                                     variable = variable,
-                                     by = by, class = "logical",
-                                     dichotomous_value = TRUE,
-                                     sort = "alphanumeric", percent = "column",
-                                     stat_display = "{n}") %>%
+  t2 <- summarize_categorical_survey(
+    data = data_is_na,
+    variable = variable,
+    by = by,
+    dichotomous_value = TRUE,
+    sort = "alphanumeric", percent = "column",
+    stat_display = "{n}"
+  ) %>%
     select(-.data$stat_display) %>%
-    rename(p_miss = .data$p,
-           N_obs = .data$N,
-           N_miss = .data$n,
-           p_miss_unweighted = .data$p_unweighted,
-           N_obs_unweighted = .data$N_unweighted,
-           N_miss_unweighted = .data$n_unweighted) %>%
-    mutate(N_nonmiss = .data$N_obs - .data$N_miss,
-           p_nonmiss = 1 - .data$p_miss,
-           N_nonmiss_unweighted = .data$N_obs_unweighted - .data$N_miss_unweighted,
-           p_nonmiss_unweighted = 1 - .data$p_miss_unweighted)
+    rename(
+      p_miss = .data$p,
+      N_obs = .data$N,
+      N_miss = .data$n,
+      p_miss_unweighted = .data$p_unweighted,
+      N_obs_unweighted = .data$N_unweighted,
+      N_miss_unweighted = .data$n_unweighted
+    ) %>%
+    mutate(
+      N_nonmiss = .data$N_obs - .data$N_miss,
+      p_nonmiss = 1 - .data$p_miss,
+      N_nonmiss_unweighted = .data$N_obs_unweighted - .data$N_miss_unweighted,
+      p_nonmiss_unweighted = 1 - .data$p_miss_unweighted
+    )
 
   # returning table will all stats
-  merge_vars <- switch(!is.null(by), c("by", "variable")) %||% "variable"
+  merge_vars <- switch(!is.null(by),
+    c("by", "variable")
+  ) %||% "variable"
   return <- left_join(t1, t2, by = merge_vars)
 
+  # adding variables needed for inlin_text()
+  if ("by" %in% names(return)) {
+    return$label <- return$by
+    return <-
+      return %>%
+      left_join(df_by(data, by)[c("by", "by_col")], by = "by") %>%
+      rename(col_name = .data$by_col)
+  }
+  else if ("variable_levels" %in% names(return)) {
+    return$label <- as.character(return$variable_levels)
+    return$col_name <- "stat_0"
+  }
+  else {
+    return$label <- var_label
+    return$col_name <- "stat_0"
+  }
+
   return <- adding_formatting_as_attr(
     df_stats = return, data = data, variable = variable,
     summary_type = summary_type, stat_display = stat_display,
@@ -551,7 +565,7 @@ calculate_missing_row_survey <- function(data, variable, by, missing_text) {
   # passing the T/F variable through the functions to format as we do in
   # the tbl_summary output
   summarize_categorical_survey(
-    data = data, variable = variable, by = by, class = "logical",
+    data = data, variable = variable, by = by,
     dichotomous_value = TRUE, sort = "alphanumeric", percent = "column",
     stat_display = "{n}"
   ) %>%
@@ -559,10 +573,13 @@ calculate_missing_row_survey <- function(data, variable, by, missing_text) {
       data = data, variable = variable,
       summary_type = "dichotomous", stat_display = "{n}", digits = NULL
     ) %>%
-    {df_stats_to_tbl(
-      data = data, variable = variable, summary_type = "dichotomous", by = by,
-      var_label = missing_text, stat_display = "{n}", df_stats = .,
-      missing = "no", missing_text = "Doesn't Matter -- Text should never appear")} %>%
+    {
+      df_stats_to_tbl(
+        data = data, variable = variable, summary_type = "dichotomous", by = by,
+        var_label = missing_text, stat_display = "{n}", df_stats = .,
+        missing = "no", missing_text = "Doesn't Matter -- Text should never appear"
+      )
+    } %>%
     # changing row_type to missing
     mutate(row_type = "missing")
 }
@@ -576,3 +593,32 @@ c_form <- function(left = NULL, right = 1) {
   right <- paste(right, collapse = "+")
   stats::as.formula(paste(left, "~", right))
 }
+
+
+# this function removes the weight/survey columns from x$variables
+# used when columns must be selected from the survey object, and we dont want users
+# to select the weighting columns
+.remove_survey_cols <- function(x) {
+  if (is.data.frame(x)) {
+    return(x)
+  }
+  x$variables %>%
+    select(-any_of(c(
+      all.vars(x$call$id),
+      all.vars(x$call$probs),
+      all.vars(x$call$strata),
+      all.vars(x$call$fpc),
+      all.vars(x$call$weights)
+    )))
+}
+
+# Min and Max Values for survey design
+svymin <- function(x, design, na.rm = FALSE, ...) {
+  x <- all.vars(x)
+  min(design$variables[[x]], na.rm = na.rm)
+}
+
+svymax <- function(x, design, na.rm = FALSE, ...) {
+  x <- all.vars(x)
+  max(design$variables[[x]], na.rm = na.rm)
+}
