@@ -1,9 +1,15 @@
-context("test-as_flex_table")
-testthat::skip_on_cran()
+skip_on_cran()
 
 test_that("tbl_summary", {
   expect_error(tbl_summary(trial) %>% as_flex_table(), NA)
   expect_warning(tbl_summary(trial) %>% as_flex_table(), NA)
+
+  expect_error(
+    tbl_summary(trial[c("trt", "age")]) %>%
+      modify_table_styling(columns = label, footnote = "test footnote", rows = variable == "age") %>%
+      as_flex_table(),
+    NA
+  )
 })
 
 test_that("tbl_summary", {
