@@ -1,9 +1,15 @@
-context("test-as_kable_extra")
-testthat::skip_on_cran()
+skip_on_cran()
 
 test_that("tbl_summary", {
   expect_error(tbl_summary(trial) %>% as_kable_extra(), NA)
   expect_warning(tbl_summary(trial) %>% as_kable_extra(), NA)
+
+  expect_error(
+    tbl_summary(trial[c("trt", "age")]) %>%
+      modify_table_styling(columns = label, footnote = "test footnote", rows = variable == "age") %>%
+      as_kable_extra(),
+    NA
+  )
 })
 
 test_that("tbl_summary", {
@@ -53,5 +59,4 @@ test_that("tbl_merge/tbl_stack", {
   expect_warning(tbl_merge_ex1 %>% as_kable_extra(), NA)
   expect_error(tbl_stack_ex1 %>% as_kable_extra(), NA)
   expect_warning(tbl_stack_ex1 %>% as_kable_extra(), NA)
-
 })
