@@ -1,8 +1,10 @@
-context("test-modify_caption")
-testthat::skip_on_cran()
+skip_on_cran()
 
 test_that("no errors/warnings with all output types", {
-  tbl <- trial %>% select(age) %>% tbl_summary() %>% modify_caption("test caption")
+  tbl <- trial %>%
+    select(age) %>%
+    tbl_summary() %>%
+    modify_caption("test caption")
 
   expect_error(tbl %>% as_gt(), NA)
   expect_error(tbl %>% as_flex_table(), NA)
@@ -11,7 +13,9 @@ test_that("no errors/warnings with all output types", {
   expect_error(tbl %>% as_kable_extra(), NA)
   expect_error(tbl %>% as_tibble(), NA)
 
-  tbl2 <- trial %>% select(age) %>% tbl_summary() %>%
+  tbl2 <- trial %>%
+    select(age) %>%
+    tbl_summary() %>%
     modify_caption("test caption", text_interpret = "html")
   expect_error(tbl2 %>% as_gt(), NA)
 
@@ -19,8 +23,8 @@ test_that("no errors/warnings with all output types", {
   expect_error(modify_caption(trial), "*")
   expect_error(tbl_reg %>% modify_caption(letters), "*")
   expect_equal(
-    tbl_reg %>% modify_caption("{N}") %>% purrr::pluck("list_output", "caption"),
+    tbl_reg %>% modify_caption("{N}") %>% purrr::pluck("table_styling", "caption"),
     "32",
-    check.attributes = FALSE
+    ignore_attr = TRUE
   )
 })
