@@ -1,5 +1,4 @@
-context("test-tbl_stack")
-testthat::skip_on_cran()
+skip_on_cran()
 library(survival)
 t1 <-
   glm(response ~ trt, trial, family = binomial) %>%
@@ -79,5 +78,4 @@ test_that("Stacking tbl_summary objects", {
     tbl_stack(lst_summary, group_header = c("Group 1", "Group 2")),
     NA
   )
-
 })
